@@ -44,6 +44,7 @@ using std::endl;
 using Vamp::RealTime;
 
 #include <cmath>
+#include <cstdio>
 
 
 class FixedTempoEstimator::D
@@ -430,7 +431,7 @@ FixedTempoEstimator::D::calculate()
 
             if (k0 >= 0 && k0 < int(n/2)) {
 
-                int kmax = 0, kmin = 0;
+                int kmax = 0;
                 float kvmax = 0, kvmin = 0;
                 bool have = false;
 
@@ -438,8 +439,8 @@ FixedTempoEstimator::D::calculate()
 
                     if (k < 0 || k >= n/2) continue;
 
-                    if (!have || (m_r[k] > kvmax)) { kmax = k; kvmax = m_r[k]; }
-                    if (!have || (m_r[k] < kvmin)) { kmin = k; kvmin = m_r[k]; }
+                    if (!have || (m_r[k] > kvmax)) { kvmax = m_r[k]; kmax = k; }
+                    if (!have || (m_r[k] < kvmin)) { kvmin = m_r[k]; }
                     
                     have = true;
                 }
@@ -528,6 +529,8 @@ FixedTempoEstimator::D::assembleFeatures()
 
     for (int i = p0; i <= p1 && i+1 < n/2; ++i) {
 
+        if (i < 1) continue;
+        
         if (m_fr[i] > m_fr[i-1] &&
             m_fr[i] > m_fr[i+1]) {
 
